@@ -59,7 +59,7 @@ pad     -> Optional argument. Only when using padmode of PAD_NORMAL. For
 	   bytes of the unencrypted data block.
 padmode -> Optional argument, set the padding mode, must be one of PAD_NORMAL
 	   or PAD_PKCS5). Defaults to PAD_NORMAL.
-	  
+
 
 Example
 -------
@@ -153,7 +153,7 @@ class _baseDes(object):
 	def getPadMode(self):
 		"""getPadMode() -> pyDes.PAD_NORMAL or pyDes.PAD_PKCS5"""
 		return self._padmode
-		
+
 	def setPadMode(self, mode):
 		"""Sets the type of padding mode, pyDes.PAD_NORMAL or pyDes.PAD_PKCS5"""
 		self._padmode = mode
@@ -188,7 +188,7 @@ class _baseDes(object):
 			if not pad:
 				raise ValueError("Data must be a multiple of " + str(self.block_size) + " bytes in length. Use padmode=PAD_PKCS5 or set the pad character.")
 			data += (self.block_size - (len(data) % self.block_size)) * pad
-		
+
 		elif padmode == PAD_PKCS5:
 			pad_len = 8 - (len(data) % self.block_size)
 			if _pythonMajorVersion < 3:
@@ -453,8 +453,8 @@ class des(_baseDes):
 
 	def __permutate(self, table, block):
 		"""Permutate this block with the specified table"""
-		return list(map(lambda x: block[x], table))
-	
+		return [block[i] for i in table]
+
 	# Transform the secret key, so that it is ready for data processing
 	# Create the 16 subkeys, K[1] - K[16]
 	def __create_sub_keys(self):
@@ -506,7 +506,7 @@ class des(_baseDes):
 			self.R = self.__permutate(des.__expansion_table, self.R)
 
 			# Exclusive or R[i - 1] with K[i], create B[1] to B[8] whilst here
-			self.R = list(map(lambda x, y: x ^ y, self.R, self.Kn[iteration]))
+			self.R = [b ^ k for b, k in zip(self.R, self.Kn[iteration])]
 			B = [self.R[:6], self.R[6:12], self.R[12:18], self.R[18:24], self.R[24:30], self.R[30:36], self.R[36:42], self.R[42:]]
 			# Optimization: Replaced below commented code with above
 			#j = 0
@@ -542,7 +542,7 @@ class des(_baseDes):
 			self.R = self.__permutate(des.__p, Bn)
 
 			# Xor with L[i - 1]
-			self.R = list(map(lambda x, y: x ^ y, self.R, self.L))
+			self.R = [b ^ l for b, l in zip(self.R, self.L)]
 			# Optimization: This now replaces the below commented code
 			#j = 0
 			#while j < len(self.R):
@@ -554,7 +554,7 @@ class des(_baseDes):
 
 			i += 1
 			iteration += iteration_adjustment
-		
+
 		# Final permutation of R[16]L[16]
 		self.final = self.__permutate(des.__fp, self.R + self.L)
 		return self.final
@@ -597,13 +597,13 @@ class des(_baseDes):
 			#	result.append(dict[data[i:i+8]])
 			#	i += 8
 			#	continue
-				
+
 			block = self.__String_to_BitList(data[i:i+8])
 
 			# Xor with IV if using CBC mode
 			if self.getMode() == CBC:
 				if crypt_type == des.ENCRYPT:
-					block = list(map(lambda x, y: x ^ y, block, iv))
+					block = [b ^ v for b, v in zip(block, iv)]
 					#j = 0
 					#while j < len(block):
 					#	block[j] = block[j] ^ iv[j]
@@ -612,7 +612,7 @@ class des(_baseDes):
 				processed_block = self.__des_crypt(block, crypt_type)
 
 				if crypt_type == des.DECRYPT:
-					processed_block = list(map(lambda x, y: x ^ y, processed_block, iv))
+					processed_block = [b ^ v for b, v in zip(processed_block, iv)]
 					#j = 0
 					#while j < len(processed_block):
 					#	processed_block[j] = processed_block[j] ^ iv[j]
